<?php

namespace TecFood\Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DependencyInjection\InstanceManager;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;

class Aplicativos extends \Teknisa\Libs\Controller\CRUD
{
    protected $connection;
    protected $dataSourceName;
    protected $fileServerFilesUrl;
    protected $newCode;

    public function __construct($crudService, $environment, $connection, $newCode)
    {
        parent::__construct($crudService, $environment);
        $this->connection = $connection;
        $this->newCode = $newCode;
    }

    private function getFileServerFilesUrl()
    {
        $instanceManager = InstanceManager::getInstance();
        return $instanceManager->getParameter('fileserverfilesurl');
    }

    public function save(Request $request, Response $response)
    {
        try {
            $this->dataSourceName = 'appconfig';
            $rows = $this->crudService->getRowsToSave($request, $this->dataSourceName);
            $rowsToSave = [];
            foreach ($rows as $row) {
                $row['NRAPPCONFIG'] = $row['__is_new'] ? $this->newCode->getCodeByTableName($this->dataSourceName, $this->environment->getNrOrg(), 1, 10, true) : $row['NRAPPCONFIG'];
                $imageCol = array_key_exists("URLLOGO", $row) ? $row['URLLOGO'] : false;
                if ($imageCol && gettype($imageCol) !== "string") {
                    $imageColValue = null;
                    if (gettype($imageCol) === "array") {
                        if (sizeof($imageCol) > 0) {
                            $fileObject = $imageCol[0];
                            if (gettype($fileObject) === "array" && array_key_exists("type", $fileObject) && array_key_exists("path", $fileObject)) {
                                $fileType = $fileObject['type'];
                                if (substr($fileType, 0, 5) === "image") {
                                    $imageColValue = $fileObject['path'];
                                }
                            }
                        }
                    }
                    $row['URLLOGO'] = $imageColValue;
                } else if ($imageCol && gettype($imageCol) === "string") {
                    $row['URLLOGO'] = str_replace($this->getFileServerFilesUrl(), "", $row['URLLOGO']);
                }
                array_push($rowsToSave, $row);
            }
            $this->crudService->save($this->dataSourceName, $rowsToSave);
            foreach ($rowsToSave as &$row) {
                if($row['URLLOGO'] != null){
                    $row['URLLOGO'] = $this->getFileServerFilesUrl().$row['URLLOGO'];
                }
            }
            $response->addDataSet(new DataSet("columnsToReturn", $this->crudService->getColumnsToReturn()));
            $response->addDataSet(new DataSet("rowSaved", $rowsToSave));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

    public function find(DTO\Request\Filter $request, DTO\Response $response)
    {
        try {
            $this->dataSourceName = "appconfig";
            $filterCriteria = $request->getFilterCriteria();

            $conditions = $filterCriteria->getConditions();
            $page = $filterCriteria->getPage();
            $pageSize = $filterCriteria->getPageSize();

            $dataSet = $this->crudService->getFilteredDataSet($this->dataSourceName, $conditions, $page, $pageSize);

            $responseRows = [];
            foreach ($dataSet->getRows() as $row) {
                $imageCol = array_key_exists("URLLOGO", $row) ? $row['URLLOGO'] : false;
                if ($imageCol && gettype($imageCol) === "string") {
                    $row['URLLOGO'] = $this->getFileServerFilesUrl() . $row['URLLOGO'];
                }
                array_push($responseRows, $row);
            }

            $responseDataSet = new DataSet($this->dataSourceName, $responseRows);
            $response->setDataSets([$responseDataSet]);

        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }

}
